@@ -4,7 +4,7 @@ use warnings;
 
 require 5.008_001;
 
-our $VERSION = '0.20.03';
+our $VERSION = '0.26';
 $VERSION = eval {$VERSION};
 
 
@@ -39,7 +39,7 @@ Net::SAML2
 
 =head1 VERSION
 
-version 0.20.03
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -54,6 +54,28 @@ version 0.20.03
                 nameid_format => $idp->format('persistent'),
         )->as_xml;
 
+        my $authnreq = Net::SAML2::Protocol::AuthnRequest->new(
+          id            => 'NETSAML2_Crypt::OpenSSL::Random::random_pseudo_bytes(16),
+          issuer        => $self->{id},		# Service Provider (SP) Entity ID
+          destination   => $sso_url,		# Identity Provider (IdP) SSO URL
+          provider_name => $provider_name,	# Service Provider (SP) Human Readable Name
+          issue_instant => DateTime->now,	# Defaults to Current Time
+        );
+
+        my $request_id = $authnreq->id;	# Store and Compare to InResponseTo
+
+        # or
+
+        my $request_id = 'NETSAML2_' . unpack 'H*', Crypt::OpenSSL::Random::random_pseudo_bytes(16);
+
+        my $authnreq = Net::SAML2::Protocol::AuthnRequest->as_xml(
+          id            => $request_id,		# Unique Request ID will be returned in response
+          issuer        => $self->{id},		# Service Provider (SP) Entity ID
+          destination   => $sso_url,		# Identity Provider (IdP) SSO URL
+          provider_name => $provider_name,	# Service Provider (SP) Human Readable Name
+          issue_instant => DateTime->now,	# Defaults to Current Time
+        );
+
         my $redirect = Net::SAML2::Binding::Redirect->new(
                 key => '/path/to/SPsign-nopw-key.pem',
                 url => $sso_url,
