@@ -221,11 +221,11 @@ Net::SAML2::IdP
 
 =head1 VERSION
 
-version 0.20.03
+version 0.26
 
 =head1 SYNOPSIS
 
-  my $idp = Net::SAML2::IdP->new_from_url($IDP);
+  my $idp = Net::SAML2::IdP->new_from_url( url => $url, cacert => $cacert );
   my $sso_url = $idp->sso_url('urn:oasis:names:tc:SAML:2.0:bindings:HTTP-Redirect');
 
 =head1 NAME
