@@ -6,6 +6,7 @@ use MooseX::Types::Common::String qw/ NonEmptySimpleStr /;
 use DateTime;
 use DateTime::Format::XSD;
 use Net::SAML2::XML::Util qw/ no_comments /;
+use XML::XPath;
 
 with 'Net::SAML2::Role::ProtocolMessage';
 
@@ -113,7 +114,7 @@ Net::SAML2::Protocol::Assertion
 
 =head1 VERSION
 
-version 0.20.03
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -146,10 +147,14 @@ XML data
 
 Returns the CN attribute, if provided.
 
-=head2 valid( $audience )
+=head2 valid( $audience, $in_response_to )
 
 Returns true if this Assertion is currently valid for the given audience.
 
+Also accepts $in_response_to which it checks against the returned
+Assertion.  This is very important for security as it helps ensure
+that the assertion that was received was for the request that was made.
+
 Checks the audience matches, and that the current time is within the
 Assertions validity period as specified in its Conditions element.
 
@@ -166,7 +171,8 @@ This software is copyright (c) 2020 by Chris Andrews and Others; in detail:
             2015       Mike Wisener
             2016       Jeff Fearn
             2017       Alessandro Ranellucci
-            2019-2020  Timothy Legge
+            2019       Timothy Legge
+            2020       Timothy Legge, Wesley Schwengle
 
 
 This is free software; you can redistribute it and/or modify it under
