@@ -7,6 +7,12 @@ use MooseX::Types::URI qw/ Uri /;
 use Crypt::OpenSSL::X509;
 use XML::Generator;
 
+use Net::SAML2::Binding::POST;
+use Net::SAML2::Binding::Redirect;
+use Net::SAML2::Binding::SOAP;
+use Net::SAML2::Protocol::AuthnRequest;
+use Net::SAML2::Protocol::LogoutRequest;
+
 
 has 'url'    => (isa => Uri, is => 'ro', required => 1, coerce => 1);
 has 'id'     => (isa => Str, is => 'ro', required => 1);
@@ -254,7 +260,7 @@ Net::SAML2::SP
 
 =head1 VERSION
 
-version 0.20.03
+version 0.26
 
 =head1 SYNOPSIS
 
@@ -381,7 +387,8 @@ This software is copyright (c) 2020 by Chris Andrews and Others; in detail:
   Copyright 2010-2011  Chris Andrews
             2012       Peter Marschall
             2017       Alessandro Ranellucci
-            2019-2020  Timothy Legge
+            2019       Timothy Legge
+            2020       Timothy Legge, Wesley Schwengle
 
 
 This is free software; you can redistribute it and/or modify it under
